getByIpAddress = {
    'id': 12345,
    'ipAddress': '10.0.1.37',
    'isBroadcast': False,
    'isGateway': False,
    'isNetwork': False,
    'isReserved': False,
    'subnetId': 5678,
    "hardware": {
        "id": 12856,
        "fullyQualifiedDomainName": "unit.test.com"
    },
    "subnet": {
        "broadcastAddress": "10.0.1.91",
        "cidr": 26,
        "gateway": "10.47.16.129",
        "id": 258369,
        "isCustomerOwned": False,
        "isCustomerRoutable": False,
        "modifyDate": "2019-04-02T13:45:52-06:00",
        "netmask": "255.255.255.192",
        "networkIdentifier": "10.0.1.38",
        "networkVlanId": 1236987,
        "sortOrder": "0",
        "subnetType": "PRIMARY",
        "totalIpAddresses": "64",
        "usableIpAddressCount": "61",
        "version": 4
    }
}

editObject = True
