# pylint: skip-file
HARDWARE_ITEMS = [
    {'attributes': [],
     'capacity': '999',
     'description': 'Unknown',
     'itemCategory': {'categoryCode': 'unknown', 'id': 325},
     'keyName': 'UNKNOWN',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1245172,
                 "locationGroupId": '',
                 'itemId': 935954,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '64',
     'description': '1 IPv6 Address',
     'itemCategory': {'categoryCode': 'pri_ipv6_addresses',
                      'id': 325},
     'keyName': '1_IPV6_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 17129,
                 "locationGroupId": '',
                 'itemId': 4097,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '10',
     'description': '10 Mbps Public & Private Network Uplinks',
     'itemCategory': {'categoryCode': 'port_speed', 'id': 26},
     'keyName': '10_MBPS_PUBLIC_PRIVATE_NETWORK_UPLINKS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 272,
                 "locationGroupId": '',
                 'itemId': 186,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 5}]},
    {'attributes': [],
     'capacity': '0',
     'description': 'Ubuntu Linux 14.04 LTS Trusty Tahr (64 bit)',
     'itemCategory': {'categoryCode': 'os', 'id': 12},
     'keyName': 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 37650,
                 "locationGroupId": '',
                 'itemId': 4702,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 9}],
     'softwareDescription': {'id': 1362,
                             'longDescription': 'Ubuntu / 14.04-64',
                             'referenceCode': 'UBUNTU_14_64'}},
    {'attributes': [],
     'capacity': '1',
     'description': '1 IP Address',
     'itemCategory': {'categoryCode': 'pri_ip_addresses', 'id': 13},
     'keyName': '1_IP_ADDRESS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 21,
                 "locationGroupId": '',
                 'itemId': 15,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [{'attributeTypeKeyName': 'RECLAIM_BYPASS',
                     'id': 1014}],
     'description': 'Unlimited SSL VPN Users',
     'itemCategory': {'categoryCode': 'vpn_management', 'id': 31},
     'keyName': 'SSL_VPN_USERS_1_PPTP_VPN_USER_PER_ACCOUNT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 420,
                 "locationGroupId": '',
                 'itemId': 309,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'description': 'Reboot / KVM over IP',
     'itemCategory': {'categoryCode': 'remote_management',
                      'id': 46},
     'keyName': 'REBOOT_KVM_OVER_IP',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 906,
                 "locationGroupId": '',
                 'itemId': 504,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 0}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'id': 22505,
                 "locationGroupId": '',
                 'itemId': 4481,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 98}]},
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB_2',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1800,
                 "locationGroupId": '',
                 'itemId': 439,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'setupFee': '0',
                 'sort': 99}]}]

ENTERPRISE_PACKAGE = {
    'categories': [
        {'categoryCode': 'storage_service_enterprise'}
    ],
    'id': 240,
    'name': 'Endurance',
    'items': [
        {
            'capacity': '0',
            'itemCategory': {'categoryCode': 'storage_service_enterprise'},
            'keyName': 'CODENAME_PRIME_STORAGE_SERVICE',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_service_enterprise'}
                    ],
                    'id': 45058,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'itemCategory': {'categoryCode': 'storage_file'},
            'keyName': 'FILE_STORAGE_2',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_file'}
                    ],
                    'id': 45108,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'itemCategory': {'categoryCode': 'storage_block'},
            'keyName': 'BLOCK_STORAGE_2',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_block'}
                    ],
                    'id': 45098,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '10',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '10_GB_STORAGE_SPACE',
            'prices': [
                {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 46160,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '300',
                    'capacityRestrictionMinimum': '300',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 46170,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '20',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '20_GB_PERFORMANCE_STORAGE_SPACE',
            'prices': [
                {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 45860,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'performance_storage_replication'}
                    ],
                    'id': 46659,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'id': 45128,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '1000',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '1000_GB_PERFORMANCE_STORAGE_SPACE',
            'prices': [
                {
                    'capacityRestrictionMaximum': '300',
                    'capacityRestrictionMinimum': '300',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'performance_storage_replication'}
                    ],
                    'id': 46789,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '300',
                    'capacityRestrictionMinimum': '300',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'id': 45318,
                    'locationGroupId': ''
                }
            ]
        }, {
            'attributes': [
                {'value': '300'}
            ],
            'capacity': '300',
            'itemCategory': {'categoryCode': 'storage_tier_level'},
            'keyName': 'WRITEHEAVY_TIER',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_tier_level'}
                    ],
                    'id': 45088,
                    'locationGroupId': ''
                }
            ]
        }, {
            'attributes': [
                {'value': '200'}
            ],
            'capacity': '200',
            'itemCategory': {'categoryCode': 'storage_tier_level'},
            'keyName': 'READHEAVY_TIER',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_tier_level'}
                    ],
                    'id': 45078,
                    'locationGroupId': ''
                }
            ]
        }
    ]
}

PERFORMANCE_PACKAGE = {
    'categories': [
        {'categoryCode': 'performance_storage_iscsi'},
        {'categoryCode': 'performance_storage_nfs'}
    ],
    'id': 222,
    'name': 'Performance',
    'items': [
        {
            'capacity': '0',
            'itemCategory': {'categoryCode': 'performance_storage_iscsi'},
            'keyName': 'BLOCK_STORAGE_PERFORMANCE_ISCSI',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'performance_storage_iscsi'}
                    ],
                    'id': 40672,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'itemCategory': {'categoryCode': 'performance_storage_nfs'},
            'keyName': 'FILE_STORAGE_PERFORMANCE_NFS',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'performance_storage_nfs'}
                    ],
                    'id': 40662,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '20',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '20_GB_PERFORMANCE_STORAGE_SPACE',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'id': 40682,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '1000',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '1000_GB_PERFORMANCE_STORAGE_SPACE',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'id': 40742,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '800',
            'itemCategory': {'categoryCode': 'performance_storage_iops'},
            'keyName': '800_IOPS_4',
            'prices': [
                {
                    'capacityRestrictionMaximum': '1000',
                    'capacityRestrictionMinimum': '100',
                    'capacityRestrictionType': 'STORAGE_SPACE',
                    'categories': [
                        {'categoryCode': 'performance_storage_iops'}
                    ],
                    'id': 41562,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '1000',
            'itemCategory': {'categoryCode': 'performance_storage_iops'},
            'keyName': '1000_IOPS',
            'prices': [
                {
                    'capacityRestrictionMaximum': '20',
                    'capacityRestrictionMinimum': '20',
                    'capacityRestrictionType': 'STORAGE_SPACE',
                    'categories': [
                        {'categoryCode': 'performance_storage_iops'}
                    ],
                    'id': 40882,
                    'locationGroupId': ''
                }
            ]
        }
    ]
}

SAAS_PACKAGE = {
    'categories': [
        {'categoryCode': 'storage_as_a_service'}
    ],
    'id': 759,
    'name': 'Storage As A Service (StaaS)',
    'items': [
        {
            'capacity': '0',
            'keyName': '',
            'prices': [
                {
                    'id': 189433,
                    'categories': [
                        {'categoryCode': 'storage_as_a_service'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'keyName': '',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_block'}
                    ],
                    'id': 189443,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'keyName': '',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_file'}
                    ],
                    'id': 189453,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '999',
            'capacityMinimum': '500',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '500_999_GBS',
            'prices': [
                {
                    'id': 189993,
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '1999',
            'capacityMinimum': '1000',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '1000_1999_GBS',
            'prices': [
                {
                    'id': 190113,
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '12000',
            'capacityMinimum': '1',
            'keyName': 'STORAGE_SPACE_FOR_2_IOPS_PER_GB',
            'prices': [
                {
                    'id': 193433,
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '12000',
            'capacityMinimum': '1',
            'keyName': 'STORAGE_SPACE_FOR_4_IOPS_PER_GB',
            'prices': [
                {
                    'id': 194763,
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '10000',
            'capacityMinimum': '100',
            'keyName': '',
            'itemCategory': {'categoryCode': 'performance_storage_iops'},
            'prices': [
                {
                    'capacityRestrictionMaximum': '999',
                    'capacityRestrictionMinimum': '500',
                    'capacityRestrictionType': 'STORAGE_SPACE',
                    'categories': [
                        {'categoryCode': 'performance_storage_iops'}
                    ],
                    'id': 190053,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '20000',
            'capacityMinimum': '100',
            'keyName': '',
            'itemCategory': {'categoryCode': 'performance_storage_iops'},
            'prices': [
                {
                    'capacityRestrictionMaximum': '1999',
                    'capacityRestrictionMinimum': '1000',
                    'capacityRestrictionType': 'STORAGE_SPACE',
                    'categories': [
                        {'categoryCode': 'performance_storage_iops'}
                    ],
                    'id': 190173,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '200',
            'itemCategory': {'categoryCode': 'storage_tier_level'},
            'keyName': '',
            'prices': [
                {
                    'id': 193373,
                    'categories': [
                        {'categoryCode': 'storage_tier_level'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '300',
            'itemCategory': {'categoryCode': 'storage_tier_level'},
            'keyName': '',
            'prices': [
                {
                    'id': 194703,
                    'categories': [
                        {'categoryCode': 'storage_tier_level'}
                    ],
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '10',
            'keyName': '',
            'prices': [
                {
                    'capacityRestrictionMaximum': '48000',
                    'capacityRestrictionMinimum': '100',
                    'capacityRestrictionType': 'IOPS',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 191193,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 193613,
                    'locationGroupId': ''
                }, {
                    'capacityRestrictionMaximum': '300',
                    'capacityRestrictionMinimum': '300',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 194943,
                    'locationGroupId': ''}]
        }, {
            'capacity': '20',
            'keyName': '',
            'prices': [
                {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 193853,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'itemCategory': {
                'categoryCode': 'performance_storage_replication'
            },
            'keyName': 'REPLICATION_FOR_IOPSBASED_PERFORMANCE',
            'prices': [
                {
                    'capacityRestrictionMaximum': '48000',
                    'capacityRestrictionMinimum': '1',
                    'capacityRestrictionType': 'IOPS',
                    'categories': [
                        {'categoryCode': 'performance_storage_replication'}
                    ],
                    'id': 192033,
                    'locationGroupId': ''
                }
            ]
        }, {
            'capacity': '0',
            'itemCategory': {
                'categoryCode': 'performance_storage_replication'
            },
            'keyName': 'REPLICATION_FOR_TIERBASED_PERFORMANCE',
            'prices': [
                {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'performance_storage_replication'}
                    ],
                    'id': 194693,
                    'locationGroupId': ''
                }
            ]
        }
    ]
}

SAAS_REST_PACKAGE = {
    'categories': [
        {'categoryCode': 'storage_as_a_service'}
    ],
    'id': 759,
    'name': 'Storage As A Service (StaaS)',
    'items': [
        {
            'capacity': '0',
            'keyName': '',
            'prices': [
                {
                    'id': 189433,
                    'categories': [
                        {'categoryCode': 'storage_as_a_service'}
                    ],
                    'locationGroupId': None
                }
            ]
        }, {
            'capacity': '20',
            'keyName': '',
            'prices': [
                {
                    'capacityRestrictionMaximum': '200',
                    'capacityRestrictionMinimum': '200',
                    'capacityRestrictionType': 'STORAGE_TIER_LEVEL',
                    'categories': [
                        {'categoryCode': 'storage_snapshot_space'}
                    ],
                    'id': 193853,
                    'locationGroupId': None
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '1999',
            'capacityMinimum': '1000',
            'itemCategory': {'categoryCode': 'performance_storage_space'},
            'keyName': '1000_1999_GBS',
            'prices': [
                {
                    'id': 190113,
                    'categories': [
                        {'categoryCode': 'performance_storage_space'}
                    ],
                    'locationGroupId': None
                }
            ]
        }, {
            'capacity': '0',
            'capacityMaximum': '20000',
            'capacityMinimum': '100',
            'keyName': '',
            'itemCategory': {'categoryCode': 'performance_storage_iops'},
            'prices': [
                {
                    'capacityRestrictionMaximum': '1999',
                    'capacityRestrictionMinimum': '1000',
                    'capacityRestrictionType': 'STORAGE_SPACE',
                    'categories': [
                        {'categoryCode': 'performance_storage_iops'}
                    ],
                    'id': 190173,
                    'locationGroupId': None
                }
            ]
        }, {
            'capacity': '0',
            'keyName': '',
            'prices': [
                {
                    'categories': [
                        {'categoryCode': 'storage_file'}
                    ],
                    'id': 189453,
                    'locationGroupId': None
                }
            ]
        }
    ]
}

activePreset1 = {
    'description': 'Single Xeon 1270, 8GB Ram, 2x1TB SATA disks, Non-RAID',
    'id': 64,
    'isActive': '1',
    'keyName': 'S1270_8GB_2X1TBSATA_NORAID',
    'name': 'S1270 8GB 2X1TBSATA NORAID',
    'packageId': 200,
    'prices': [
        {
            "hourlyRecurringFee": "1.18",
            "id": 165711,
            "locationGroupId": '',
            "recurringFee": "780",
        }
    ]
}

activePreset2 = {
    'description': 'Dual Xeon Gold, 384GB Ram, 4x960GB SSD, RAID 10',
    'id': 65,
    'isActive': '1',
    'keyName': 'DGOLD_6140_384GB_4X960GB_SSD_SED_RAID_10',
    'name': 'DGOLD 6140 384GB 4X960GB SSD SED RAID 10',
    'packageId': 200,
    'prices': [
        {
            "hourlyRecurringFee": "1.18",
            "id": 165711,
            "locationGroupId": '',
            "recurringFee": "780",
        }
    ]
}

getAllObjects = [{
    'activePresets': [activePreset1],
    'accountRestrictedActivePresets': [activePreset2],
    'description': 'Bare Metal Server',
    'firstOrderStepId': 1,
    'id': 200,
    'isActive': 1,
    'items': HARDWARE_ITEMS,
    'name': 'Bare Metal Server',
    'regions': [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
                 'keyname': 'WASHINGTON_DC',
                 'location': {'location': {'id': 37473,
                                           'longName': 'Washington 1',
                                           'name': 'wdc01'}},
                 'sortOrder': 10}],
    'subDescription': 'Bare Metal Server',
    'unitSize': 1,
    "itemPrices": [
        {
            "hourlyRecurringFee": ".027",
            "id": 205911,
            "laborFee": "0",
            "locationGroupId": 505,
            "capacityRestrictionMaximum": "40",
            "capacityRestrictionMinimum": "40",
            "capacityRestrictionType": "CORE",
            "item": {
                "capacity": "0",
                "description": "Load Balancer Uptime",
                "id": 10785,
                "keyName": "LOAD_BALANCER_UPTIME",
            }
        },
        {
            "hourlyRecurringFee": "0",
            "id": 199467,
            "laborFee": "0",
            "locationGroupId": '',
            "recurringFee": "0",
            "item": {
                "capacity": "0",
                "description": "Load Balancer Bandwidth",
                "id": 10051,
                "keyName": "LOAD_BALANCER_BANDWIDTH",
            }
        },
        {
            "hourlyRecurringFee": ".028",
            "id": 205913,
            "laborFee": "0",
            "locationGroupId": 507,
            "item": {
                "capacity": "0",
                "description": "Load Balancer Uptime",
                "id": 10785,
                "keyName": "LOAD_BALANCER_UPTIME",
            }
        }]
}]

getItems = [
    {
        'id': 1234,
        'keyName': 'KeyName01',
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'softwareDescription': {
            'id': 1228,
            'longDescription': 'Redhat EL 5.10-64',
            'referenceCode': 'REDHAT_5_64'
        },
        'prices': [{'id': 1122,
                    'hourlyRecurringFee': 0.10,
                    'recurringFee': 0.10,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 2233,
        'keyName': 'KeyName02',
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 4477,
                    'hourlyRecurringFee': 0.10,
                    'recurringFee': 0.10,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 1239,
        'keyName': 'KeyName03',
        'capacity': '2',
        'description': 'RAM',
        'itemCategory': {'categoryCode': 'RAM'},
        'prices': [{'id': 1133,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 3,
                                    'name': 'RAM',
                                    'categoryCode': 'ram'}]}],
    },
    {
        'id': 1240,
        'keyName': 'KeyName014',
        'capacity': '4',
        'units': 'PRIVATE_CORE',
        'description': 'Computing Instance (Dedicated)',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1007,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 1250,
        'keyName': 'KeyName015',
        'capacity': '4',
        'units': 'CORE',
        'description': 'Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 1144,
                    'locationGroupId': None,
                    'hourlyRecurringFee': 0.10,
                    'recurringFee': 0.10,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 112233,
        'keyName': 'KeyName016',
        'capacity': '55',
        'units': 'CORE',
        'description': 'Computing Instance',
        'itemCategory': {'categoryCode': 'Computing Instance'},
        'prices': [{'id': 332211,
                    'locationGroupId': 1,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 80,
                                    'name': 'Computing Instance',
                                    'categoryCode': 'guest_core'}]}],
    },
    {
        'id': 4439,
        'keyName': 'KeyName017',
        'capacity': '1',
        'description': '1 GB iSCSI Storage',
        'itemCategory': {'categoryCode': 'iscsi'},
        'prices': [{'id': 2222, 'hourlyRecurringFee': 0.10, 'recurringFee': 0.10}],
    },
    {
        'id': 1121,
        'keyName': 'KeyName081',
        'capacity': '20',
        'description': '20 GB iSCSI snapshot',
        'itemCategory': {'categoryCode': 'iscsi_snapshot_space'},
        'prices': [{'id': 2014, 'hourlyRecurringFee': 0.10}],
    },
    {
        'id': 4440,
        'keyName': 'KeyName019',
        'capacity': '4',
        'description': '4 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 4444, 'hourlyRecurringFee': 0.10, 'recurringFee': 0.10}],
    },
    {
        'id': 8880,
        'keyName': 'KeyName0199',
        'capacity': '8',
        'description': '8 Portable Public IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_pub'},
        'prices': [{'id': 8888, 'hourlyRecurringFee': 0.10, 'recurringFee': 0.10}],
    },
    {
        'id': 44400,
        'keyName': 'KeyName0155',
        'capacity': '4',
        'description': '4 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 44441, 'hourlyRecurringFee': 0.10, 'recurringFee': 0.10}],
    },
    {
        'id': 88800,
        'keyName': 'KeyName0144',
        'capacity': '8',
        'description': '8 Portable Private IP Addresses',
        'itemCategory': {'categoryCode': 'sov_sec_ip_addresses_priv'},
        'prices': [{'id': 88881, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
    },
    {
        'id': 10,
        'keyName': 'KeyName0341',
        'capacity': '0',
        'description': 'Global IPv4',
        'itemCategory': {'categoryCode': 'global_ipv4'},
        'prices': [{'id': 11, 'hourlyRecurringFee': 0.0, 'recurringFee': 0.0}],
    },
    {
        'id': 66464,
        'keyName': '1_IPV6_ADDRESS',
        'capacity': '64',
        'description': '/64 Block Portable Public IPv6 Addresses',
        'itemCategory': {'categoryCode': 'static_ipv6_addresses'},
        'prices': [{'id': 664641, 'hourlyRecurringFee': '0', 'locationGroupId': '', 'recurringFee': '0'}],
    },
    {
        'id': 610,
        'keyName': 'KeyName031',
        'capacity': '0',
        'description': 'Global IPv6',
        'itemCategory': {'categoryCode': 'global_ipv6'},
        'prices': [{'id': 611, 'hourlyRecurringFee': 0.10, 'recurringFee': 0.10}],
    },
    {'attributes': [],
     'capacity': '0',
     'description': '0 GB Bandwidth',
     'itemCategory': {'categoryCode': 'bandwidth', 'id': 10},
     'keyName': 'BANDWIDTH_0_GB_2',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 1800,
                 "locationGroupId": '',
                 'itemId': 439,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'setupFee': '0',
                 'sort': 99}]},
    {'attributes': [],
     'capacity': '10',
     'description': '10 Mbps Public & Private Network Uplinks',
     'itemCategory': {'categoryCode': 'port_speed', 'id': 26},
     'keyName': '10_MBPS_PUBLIC_PRIVATE_NETWORK_UPLINKS',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0',
                 'id': 272,
                 "locationGroupId": '',
                 'itemId': 186,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0',
                 'setupFee': '0',
                 'sort': 5}]},
    {'attributes': [],
     'capacity': '0',
     'description': 'Ubuntu Linux 14.04 LTS Trusty Tahr (64 bit)',
     'itemCategory': {'categoryCode': 'os', 'id': 12},
     'keyName': 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT',
     'prices': [{'accountRestrictions': [],
                 'currentPriceFlag': '',
                 'hourlyRecurringFee': '0.10',
                 'id': 37650,
                 "locationGroupId": '',
                 'itemId': 4702,
                 'laborFee': '0',
                 'onSaleFlag': '',
                 'oneTimeFee': '0',
                 'quantity': '',
                 'recurringFee': '0.1',
                 'setupFee': '0.1',
                 'sort': 9}],
     'softwareDescription': {'id': 1362,
                             'longDescription': 'Ubuntu / 14.04-64',
                             'referenceCode': 'UBUNTU_14_64'}}
]

getItemPricesISCSI = [
    {
        'currentPriceFlag': '',
        'id': 2152,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 46626,
                               'itemPriceId': 2152, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '.35',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22501,
        'item': {'capacity': '1',
                 'description': '1 GB iSCSI SAN Storage',
                 'id': 1111,
                 'softwareDescriptionId': '',
                 'units': 'GB',
                 'upgradeItemId': 547},
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{
            'id': 252983,
            'itemPriceId': 22501, 'packageId': 0
        }],
        'quantity': '',
        'recurringFee': '0',
        'setupFee': '0',
        'sort': 0
    },
    {
        'currentPriceFlag': '',
        'id': 22441,
        'item': {
            'capacity': '1',
            'description': '1 GB iSCSI SAN Storage',
            'id': 1111,
            'softwareDescriptionId': '',
            'units': 'GB',
            'upgradeItemId': 547
        },
        'itemId': 1111,
        'laborFee': '0',
        'onSaleFlag': '',
        'oneTimeFee': '0',
        'packageReferences': [{'id': 250326,
                               'itemPriceId': 22441, 'packageId': 0}],
        'quantity': '',
        'recurringFee': '15',
        'setupFee': '0',
        'sort': 0
    }]

getItemsVS = [
    {
        'id': 1234,
        'keyName': 'KeyName01',
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'softwareDescription': {
            'id': 1228,
            'longDescription': 'Redhat EL 5.10-64',
            'referenceCode': 'REDHAT_5_64'
        },
        'prices': [{'id': 1122,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 2233,
        'keyName': 'KeyName02',
        'capacity': '1000',
        'description': 'Public & Private Networks',
        'itemCategory': {'categoryCode': 'Uplink Port Speeds'},
        'prices': [{'id': 4477,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 26,
                                    'name': 'Uplink Port Speeds',
                                    'categoryCode': 'port_speed'}]}],
    },
    {
        'id': 1239,
        'keyName': 'KeyName03',
        'capacity': '2',
        'description': 'RAM',
        'itemCategory': {'categoryCode': 'RAM'},
        'prices': [{'id': 1133,
                    'hourlyRecurringFee': 0.0,
                    'recurringFee': 0.0,
                    'categories': [{'id': 3,
                                    'name': 'RAM',
                                    'categoryCode': 'ram'}]}],
    }
]

verifyOrderDH = {
    'preTaxSetup': '0',
    'storageGroups': [],
    'postTaxRecurring': '3.164',
    'billingOrderItemId': '',
    'presetId': '',
    'hardware': [
        {
            'domain': 't.com',
            'hostname': 't',
            'bareMetalInstanceFlag': '',
            'hardwareStatusId': '',
            'primaryBackendNetworkComponent': {
                'router': {
                    'id': 51218
                },
                'networkVlanId': ''
            },
            'accountId': ''
        }
    ],
    'prices': [
        {
            'itemId': 10195,
            'setupFee': '0',
            'recurringFee': '0',
            'hourlyRecurringFee': '3.164',
            'oneTimeFee': '0',
            'id': 200269,
            'item': {
                'thirdPartyPolicyAssignments': [],
                'capacity': '56',
                'description': '56 Cores X 242 RAM X 1.2 TB',
                'bundle': [
                    {
                        'category': {
                            'categoryCode': 'dedicated_host_ram',
                            'id': 850,
                            'name': 'Dedicated Host RAM'
                        },
                        'itemPriceId': 200301,
                        'itemPrice': {
                            'itemId': 10199,
                            'setupFee': '0',
                            'recurringFee': '0',
                            'hourlyRecurringFee': '0',
                            'oneTimeFee': '0',
                            'id': 200301,
                            'laborFee': '0'
                        },
                        'bundleItemId': 10195,
                        'bundleItem': {
                            'units': 'CORE',
                            'keyName': '56_CORES_X_242_RAM_X_1_4_TB',
                            'capacity': '56',
                            'description': '56 Cores X 242 RAM X 1.2 TB',
                            'id': 10195
                        },
                        'id': 41763
                    },
                    {
                        'category': {
                            'categoryCode': 'dedicated_host_disk',
                            'id': 851,
                            'name': 'Dedicated Host Disk'
                        },
                        'itemPriceId': 200299,
                        'itemPrice': {
                            'itemId': 10197,
                            'setupFee': '0',
                            'recurringFee': '0',
                            'hourlyRecurringFee': '0',
                            'oneTimeFee': '0',
                            'id': 200299,
                            'laborFee': '0'
                        },
                        'bundleItemId': 10195,
                        'bundleItem': {
                            'units': 'CORE',
                            'keyName': '56_CORES_X_242_RAM_X_1_4_TB',
                            'capacity': '56',
                            'description': '56 Cores X 242 RAM X 1.2 TB',
                            'id': 10195
                        },
                        'id': 41761
                    }
                ],
                'keyName': '56_CORES_X_242_RAM_X_1_4_TB',
                'units': 'CORE',
                'id': 10195
            },
            'laborFee': '0',
            'categories': [
                {
                    'categoryCode': 'dedicated_virtual_hosts',
                    'id': 848,
                    'name': 'Dedicated Host'
                }
            ]
        }
    ],
    'sendQuoteEmailFlag': '',
    'packageId': 813,
    'useHourlyPricing': True,
    'preTaxRecurringMonthly': '0',
    'message': '',
    'preTaxRecurring': '3.164',
    'primaryDiskPartitionId': '',
    'locationObject': {
        'id': 138124,
        'name': 'dal05',
        'longName': 'Dallas 5'
    },
    'taxCompletedFlag': False,
    'isManagedOrder': '',
    'imageTemplateId': '',
    'postTaxRecurringMonthly': '0',
    'resourceGroupTemplateId': '',
    'postTaxSetup': '0',
    'sshKeys': [],
    'location': '138124',
    'stepId': '',
    'proratedInitialCharge': '0',
    'totalRecurringTax': '0',
    'paymentType': '',
    'resourceGroupId': '',
    'sourceVirtualGuestId': '',
    'bigDataOrderFlag': False,
    'extendedHardwareTesting': '',
    'preTaxRecurringHourly': '3.164',
    'postTaxRecurringHourly': '3.164',
    'currencyShortName': 'USD',
    'containerSplHash': '000000003699c54000007f38ef8b0102',
    'proratedOrderTotal': '0',
    'serverCoreCount': '',
    'privateCloudOrderFlag': False,
    'totalSetupTax': '0',
    'quantity': 1
}

itemsLoadbal = [
    {
        "capacity": "0",
        "description": "Load Balancer as a Service",
        "id": 10043,
        "keyName": "LOAD_BALANCER_AS_A_SERVICE",
        "itemCategory": {
            "categoryCode": "load_balancer_as_a_service",
            "id": 1116,
            "name": "Load Balancer As A Service",
        },
        "prices": [
            {
                "hourlyRecurringFee": "0",
                "id": 199447,
                "locationGroupId": '',
                "recurringFee": "0",
            }
        ]
    },
    {
        "capacity": "0",
        "description": "Load Balancer Uptime",
        "id": 10785,
        "keyName": "LOAD_BALANCER_UPTIME",
        "itemCategory": {
            "categoryCode": "load_balancer_uptime",
            "id": 1119,
            "name": "Load Balancer Uptime",
        },
        "prices": [
            {
                "hourlyRecurringFee": ".028",
                "id": 205913,
                "locationGroupId": 507,
            }]}
]

regionsLoadbal = [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
                   'keyname': 'WASHINGTON_DC',
                   'location': {'location': {'id': 37473,
                                             'longName': 'Washington 1',
                                             'name': 'wdc01',
                                             "groups": [
                                                 {
                                                     "description": "Location Group 4",
                                                     "id": 507,
                                                     "locationGroupTypeId": 82,
                                                     "name": "Location Group 4",
                                                     "locationGroupType": {
                                                         "name": "PRICING"
                                                     }
                                                 },
                                                 {
                                                     "description": "COS Cross Region - EU",
                                                     "id": 1303,
                                                     "locationGroupTypeId": 82,
                                                     "name": "eu",
                                                     "locationGroupType": {
                                                         "name": "PRICING"
                                                     }
                                                 },
                                                 {
                                                     "description": "COS Regional Frankfurt",
                                                     "id": 1783,
                                                     "locationGroupTypeId": 82,
                                                     "name": "eu-de",
                                                     "locationGroupType": {
                                                         "name": "PRICING"
                                                     }
                                                 }
                                             ]
                                             }},
                   'sortOrder': 10}]

getAllObjectsLoadbal = [
    {
        "id": 805,
        "keyName": "LBAAS",
        "name": "Load Balancer As A Service (LBaaS)",
        "items": itemsLoadbal,
        "regions": regionsLoadbal
    }
]

getAllObjectsDH = [{
    "subDescription": "Dedicated Host",
    "name": "Dedicated Host",
    "items": [{
        "capacity": "56",
        "description": "56 Cores X 242 RAM X 1.2 TB",
        "bundleItems": [
            {
                "capacity": "1200",
                "keyName": "1_4_TB_LOCAL_STORAGE_DEDICATED_HOST_CAPACITY",
                "categories": [{
                    "categoryCode": "dedicated_host_disk"
                }]
            },
            {
                "capacity": "242",
                "keyName": "242_GB_RAM",
                "categories": [{
                    "categoryCode": "dedicated_host_ram"
                }]
            }
        ],
        "prices": [
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2099",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.164",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200269,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": "",
                "quantity": ""
            },
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2161.97",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.258",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200271,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": 503,
                "quantity": ""
            }
        ],
        "keyName": "56_CORES_X_242_RAM_X_1_4_TB",
        "id": 10195,
        "itemCategory": {
            "categoryCode": "dedicated_virtual_hosts"
        }
    }],
    "keyName": "DEDICATED_HOST",
    "unitSize": "",
    "regions": [{
        "location": {
            "locationPackageDetails": [{
                "isAvailable": 1,
                "locationId": 138124,
                "packageId": 813
            }],
            "location": {
                "statusId": 2,
                "priceGroups": [{
                    "locationGroupTypeId": 82,
                    "description": "CDN - North America - Akamai",
                    "locationGroupType": {
                        "name": "PRICING"
                    },
                    "securityLevelId": "",
                    "id": 1463,
                    "name": "NORTH-AMERICA-AKAMAI"
                }],
                "id": 138124,
                "name": "dal05",
                "longName": "Dallas 5"
            }
        },
        "keyname": "DALLAS05",
        "description": "DAL05 - Dallas",
        "sortOrder": 12
    }],
    "firstOrderStepId": "",
    "id": 813,
    "isActive": 1,
    "description": "Dedicated Host"
}]

getAllObjectsDHGpu = [{
    "subDescription": "Dedicated Host",
    "name": "Dedicated Host",
    "items": [{
        "capacity": "56",
        "description": "56 Cores x 360 RAM x 1.2 TB x 2 GPU P100 [encryption enabled]",
        "bundleItems": [
            {
                "capacity": "1200",
                "keyName": "1.2 TB Local Storage (Dedicated Host Capacity)",
                "categories": [{
                    "categoryCode": "dedicated_host_disk"
                }]
            },
            {
                "capacity": "242",
                "keyName": "2_GPU_P100_DEDICATED",
                "hardwareGenericComponentModel": {
                    "capacity": "16",
                    "id": 849,
                    "hardwareComponentType": {
                        "id": 20,
                        "keyName": "GPU"
                    }
                },
                "categories": [{
                    "categoryCode": "dedicated_host_ram"
                }]
            }
        ],
        "prices": [
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2099",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.164",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200269,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": "",
                "quantity": ""
            },
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2161.97",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.258",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200271,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": 503,
                "quantity": ""
            }
        ],
        "keyName": "56_CORES_X_484_RAM_X_1_5_TB_X_2_GPU_P100",
        "id": 10195,
        "itemCategory": {
            "categoryCode": "dedicated_virtual_hosts"
        }
    }],
    "keyName": "DEDICATED_HOST",
    "unitSize": "",
    "regions": [{
        "location": {
            "locationPackageDetails": [{
                "isAvailable": 1,
                "locationId": 138124,
                "packageId": 813
            }],
            "location": {
                "statusId": 2,
                "priceGroups": [{
                    "locationGroupTypeId": 82,
                    "description": "CDN - North America - Akamai",
                    "locationGroupType": {
                        "name": "PRICING"
                    },
                    "securityLevelId": "",
                    "id": 1463,
                    "name": "NORTH-AMERICA-AKAMAI"
                }],
                "id": 138124,
                "name": "dal05",
                "longName": "Dallas 5"
            }
        },
        "keyname": "DALLAS05",
        "description": "DAL05 - Dallas",
        "sortOrder": 12
    }],
    "firstOrderStepId": "",
    "id": 813,
    "isActive": 1,
    "description": "Dedicated Host"
}]

getRegions = [{
    "description": "WDC07 - Washington, DC",
    "keyname": "WASHINGTON07",
    "location": {
        "locationId": 2017603,
        "location": {
            "id": 2017603,
            "longName": "Washington 7",
            "name": "wdc07",
            "priceGroups": [
                {
                    "description": "COS Regional - US East",
                    "id": 1305,
                    "locationGroupTypeId": 82,
                    "name": "us-east",
                    "locationGroupType": {
                        "name": "PRICING"
                    }
                }
            ]
        }
    },
    "locations": [{
        "location": {
            "euCompliantFlag": False,
            "id": 2017603,
            "longName": "Washington 7",
            "name": "wdc07",
            "statusId": 2},
        "locationPackageDetails": [{
            "isAvailable": 1,
            "locationId": 2017603,
            "packageId": 46
        }]
    }]
}]

getItemPrices = [
    {
        "hourlyRecurringFee": ".093",
        "id": 204015,
        "recurringFee": "62",
        "categories": [
            {
                "categoryCode": "guest_core"
            }
        ],
        "item": {
            "description": "4 x 2.0 GHz or higher Cores",
            "id": 859,
            "keyName": "GUEST_CORES_4",
        },
        "pricingLocationGroup": {
            "id": 503,
            "locations": [
                {
                    "id": 449610,
                    "longName": "Montreal 1",
                    "name": "mon01",
                    "statusId": 2,
                    "regions": [
                        {
                            "description": "MON01 - Montreal",
                            "keyname": "MONTREAL",
                            "sortOrder": 94
                        }
                    ]
                },
                {
                    "id": 449618,
                    "longName": "Montreal 2",
                    "name": "mon02",
                    "statusId": 2
                },
                {
                    "id": 448994,
                    "longName": "Toronto 1",
                    "name": "tor01",
                    "statusId": 2
                },
                {
                    "id": 350993,
                    "longName": "Toronto 2",
                    "name": "tor02",
                    "statusId": 2
                },
                {
                    "id": 221894,
                    "longName": "Amsterdam 2",
                    "name": "ams02",
                    "statusId": 2,
                    "regions": [
                        {
                            "description": "AMS02 POP - Amsterdam",
                            "keyname": "AMSTERDAM02",
                            "sortOrder": 12
                        }
                    ]
                },
                {
                    "id": 265592,
                    "longName": "Amsterdam 1",
                    "name": "ams01",
                    "statusId": 2
                },
                {
                    "id": 814994,
                    "longName": "Amsterdam 3",
                    "name": "ams03",
                    "statusId": 2
                }
            ]
        }
    },
    {
        "hourlyRecurringFee": ".006",
        "id": 204663,
        "recurringFee": "4.1",
        "item": {
            "description": "100 GB (LOCAL)",
            "id": 3899,
            "keyName": "GUEST_DISK_100_GB_LOCAL_3",
        },
        "pricingLocationGroup": {
            "id": 503,
            "locations": [
                {
                    "id": 449610,
                    "longName": "Montreal 1",
                    "name": "mon01",
                    "statusId": 2
                },
                {
                    "id": 449618,
                    "longName": "Montreal 2",
                    "name": "mon02",
                    "statusId": 2
                },
                {
                    "id": 448994,
                    "longName": "Toronto 1",
                    "name": "tor01",
                    "statusId": 2
                },
                {
                    "id": 350993,
                    "longName": "Toronto 2",
                    "name": "tor02",
                    "statusId": 2
                },
                {
                    "id": 221894,
                    "longName": "Amsterdam 2",
                    "name": "ams02",
                    "statusId": 2
                },
                {
                    "id": 265592,
                    "longName": "Amsterdam 1",
                    "name": "ams01",
                    "statusId": 2
                },
                {
                    "id": 814994,
                    "longName": "Amsterdam 3",
                    "name": "ams03",
                    "statusId": 2
                }
            ]
        }
    },
    {
        "hourlyRecurringFee": ".217",
        "id": 204255,
        "recurringFee": "144",
        "item": {
            "description": "16 GB ",
            "id": 1017,
            "keyName": "RAM_16_GB",
        },
        "pricingLocationGroup": {
            "id": 503,
            "locations": [
                {
                    "id": 449610,
                    "longName": "Montreal 1",
                    "name": "mon01",
                    "statusId": 2
                },
                {
                    "id": 449618,
                    "longName": "Montreal 2",
                    "name": "mon02",
                    "statusId": 2
                },
                {
                    "id": 448994,
                    "longName": "Toronto 1",
                    "name": "tor01",
                    "statusId": 2
                },
                {
                    "id": 350993,
                    "longName": "Toronto 2",
                    "name": "tor02",
                    "statusId": 2
                },
                {
                    "id": 221894,
                    "longName": "Amsterdam 2",
                    "name": "ams02",
                    "statusId": 2
                },
                {
                    "id": 265592,
                    "longName": "Amsterdam 1",
                    "name": "ams01",
                    "statusId": 2
                },
                {
                    "id": 814994,
                    "longName": "Amsterdam 3",
                    "name": "ams03",
                    "statusId": 2
                }
            ]
        }
    }
]
getActivePresets = [
    {
        "description": "M1.64x512x25",
        "id": 799,
        "isActive": "1",
        "keyName": "M1_64X512X25",
        "name": "M1.64x512x25",
        "packageId": 835,
        "locations": [],
        "prices": [
            {
                "hourlyRecurringFee": "0",
                "id": 258963,
                "itemId": 8195,
                "recurringFee": "0",
                "setupFee": "0"
            }]
    },
    {
        "description": "M1.56x448x100",
        "id": 797,
        "isActive": "1",
        "keyName": "M1_56X448X100",
        "name": "M1.56x448x100",
        "packageId": 835,
        "locations": [],
        "prices": [
            {
                "hourlyRecurringFee": "0",
                "id": 698563,
                "itemId": 8195,
                "recurringFee": "0",
                "setupFee": "0"
            }]
    },
    {
        "description": "M1.64x512x100",
        "id": 801,
        "isActive": "1",
        "keyName": "M1_64X512X100",
        "name": "M1.64x512x100",
        "packageId": 835,
        "locations": [],
        "prices": [
            {
                "hourlyRecurringFee": "0",
                "id": 963258,
                "itemId": 8195,
                "recurringFee": "0",
                "setupFee": "0"
            }]
    }
]

getAccountRestrictedActivePresets = []

RESERVED_CAPACITY = [{"id": 1059}]
getItems_RESERVED_CAPACITY = [
    {
        'id': 12273,
        'keyName': 'B1_1X2_1_YEAR_TERM',
        'description': 'B1 1x2 1 year term',
        'capacity': 12,
        'itemCategory': {
            'categoryCode': 'reserved_capacity',
            'id': 2060,
            'name': 'Reserved Capacity',
            'quantityLimit': 20,
            'sortOrder': ''
        },
        'prices': [
            {
                'currentPriceFlag': '',
                'hourlyRecurringFee': '.032',
                'id': 217561,
                'itemId': 12273,
                'laborFee': '0',
                'locationGroupId': '',
                'onSaleFlag': '',
                'oneTimeFee': '0',
                'quantity': '',
                'setupFee': '0',
                'sort': 0,
                'tierMinimumThreshold': '',
                'categories': [
                    {
                        'categoryCode': 'reserved_capacity',
                        'id': 2060,
                        'name': 'Reserved Capacity',
                        'quantityLimit': 20,
                        'sortOrder': ''
                    }
                ]
            }
        ]
    }
]

getItems_1_IPV6_ADDRESS = [
    {
        'id': 4097,
        'keyName': '1_IPV6_ADDRESS',
        'itemCategory': {
            'categoryCode': 'pri_ipv6_addresses',
            'id': 325,
            'name': 'Primary IPv6 Addresses',
            'quantityLimit': 0,
            'sortOrder': 34
        },
        'prices': [
            {
                'currentPriceFlag': '',
                'hourlyRecurringFee': '0',
                'id': 17129,
                'itemId': 4097,
                'laborFee': '0',
                'locationGroupId': '',
                'onSaleFlag': '',
                'oneTimeFee': '0',
                'quantity': '',
                'recurringFee': '0',
                'setupFee': '0',
                'sort': 0,
                'tierMinimumThreshold': '',
                'categories': [
                    {
                        'categoryCode': 'pri_ipv6_addresses',
                        'id': 325,
                        'name': 'Primary IPv6 Addresses',
                        'quantityLimit': 0,
                        'sortOrder': 34
                    }
                ]
            }
        ]
    }
]

getObject = {
    'id': 200,
    'regions': [{'description': 'WDC01 - Washington, DC - East Coast U.S.',
                 'keyname': 'WASHINGTON_DC',
                 'location': {'location': {'id': 37473,
                                           'longName': 'Washington 1',
                                           'name': 'wdc01'}},
                 'sortOrder': 10}],
    'accountRestrictedActivePresets': [],
    'activePresets': [
        {
            'description': 'AC2.8x60x25',
            'id': 861,
            'isActive': '1',
            'keyName': 'AC2_8X60X25',
            'name': 'AC2.8x60x25',
            'packageId': 835
        },
        {
            'description': 'AC2.8x60x100',
            'id': 863,
            'isActive': '1',
            'keyName': 'AC2_8X60X100',
            'name': 'AC2.8x60x100',
            'packageId': 835
        }],
    "items": [{
        "capacity": "56",
        "description": "56 Cores x 360 RAM x 1.2 TB x 2 GPU P100 [encryption enabled]",
        "bundleItems": [
            {
                "capacity": "1200",
                "keyName": "1.2 TB Local Storage (Dedicated Host Capacity)",
                "categories": [{
                    "categoryCode": "dedicated_host_disk"
                }]
            },
            {
                "capacity": "242",
                "keyName": "2_GPU_P100_DEDICATED",
                "hardwareGenericComponentModel": {
                    "capacity": "16",
                    "id": 849,
                    "hardwareComponentType": {
                        "id": 20,
                        "keyName": "GPU"
                    }
                },
                "categories": [{
                    "categoryCode": "dedicated_host_ram"
                }, {
                    "capacity": "2",
                    "description": "2 x 2.0 GHz or higher Cores",
                    "keyName": "GUEST_CORES_2",
                    "attributes": [
                        {
                            "id": 8261,
                            "attributeTypeKeyName": "ORDER_SAVES_USAGE_FEES"
                        }
                    ],
                    "itemCategory": {
                        "categoryCode": "guest_core",
                        "id": 80
                    }}]
            }
        ],
        "prices": [
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2099",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.164",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200269,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": "",
                "quantity": ""
            },
            {
                "itemId": 10195,
                "setupFee": "0",
                "recurringFee": "2161.97",
                "tierMinimumThreshold": "",
                "hourlyRecurringFee": "3.258",
                "oneTimeFee": "0",
                "currentPriceFlag": "",
                "id": 200271,
                "sort": 0,
                "onSaleFlag": "",
                "laborFee": "0",
                "locationGroupId": 503,
                "quantity": ""
            }
        ],
        "keyName": "56_CORES_X_484_RAM_X_1_5_TB_X_2_GPU_P100",
        "id": 10195,
        "itemCategory": {
            "categoryCode": "dedicated_virtual_hosts"
        }
    }]}

getItems_vmware = [{
    "capacity": "2",
    "description": "VMware vSAN Enterprise Tier III 65 - 124 TB 6.x",
    "id": 9567,
    "itemTaxCategoryId": 166,
    "keyName": "VMWARE_VSAN_ENTERPRISE_TIER_III_65_124_TB_6_X_2",
    "softwareDescriptionId": 1979,
    "units": "CPU",
    "itemCategory": {
        "categoryCode": "software_license",
        "id": 438,
        "name": "Software License",
        "quantityLimit": 1,
    },
    "prices": [
        {
            "id": 245164,
            "itemId": 9567,
            "laborFee": "0",
            "locationGroupId": None,
            "recurringFee": "0",
            "setupFee": "0",
            "sort": 0,
        }
    ]}]

getItemsVLAN = [{
    "description": "Private Network Vlan",
    "id": 1072,
    "itemTaxCategoryId": 166,
    "keyName": "PRIVATE_NETWORK_VLAN",
    "itemCategory": {
        "categoryCode": "network_vlan",
        "id": 113,
        "name": "Network Vlan"},
    "prices": [{
        "id": 203707,
        "itemId": 1072,
        "laborFee": "0",
        "locationGroupId": 505,
        "oneTimeFee": "0",
        "recurringFee": "0",
        "setupFee": "0",
        "sort": 10,
    },
        {
            "id": 203727,
            "itemId": 1072,
            "laborFee": "0",
            "locationGroupId": 545,
            "oneTimeFee": "0",
            "recurringFee": "0",
            "setupFee": "0",
            "sort": 10,
    }]
}, {
    "description": "Public Network Vlan",
    "id": 1071,
    "itemTaxCategoryId": 166,
    "keyName": "PUBLIC_NETWORK_VLAN",
    "units": "N/A",
    "itemCategory": {
        "categoryCode": "network_vlan",
        "id": 113,
        "name": "Network Vlan",
    },
    "prices": [{
        "id": 203637,
        "itemId": 1071,
        "laborFee": "0",
        "locationGroupId": 509,
        "oneTimeFee": "0",
        "recurringFee": "0",
        "setupFee": "0",
        "sort": 10,
    },
        {
            "id": 203667,
            "itemId": 1071,
            "laborFee": "0",
            "locationGroupId": 545,
            "oneTimeFee": "0",
            "recurringFee": "0",
            "setupFee": "0",
            "sort": 10,
    }]
}
]

getAllObjectsIPSEC = [{
    "firstOrderStepId": 1,
    "id": 0,
    "isActive": 1,
    "keyName": "ADDITIONAL_PRODUCTS",
    "name": "Additional Products"}]

getItems_IPSEC = [{
    "description": "IPSEC - Standard",
    "id": 1092,
    "keyName": "IPSEC_STANDARD",
    "categories": [
        {
            "categoryCode": "network_tunnel",
            "id": 117,
            "name": "Network Tunnel",
            "quantityLimit": 0,
        },
        {
            "categoryCode": "one_time_charge",
            "id": 33,
            "name": "One Time Charge",
            "quantityLimit": 0,
        }
    ],
    "itemCategory": {
        "categoryCode": "network_tunnel",
        "id": 117,
        "name": "Network Tunnel",
        "quantityLimit": 0,
    },
    "prices": [
        {
            "id": 51379,
            "itemId": 1092,
            "laborFee": "0",
            "locationGroupId": 503,
            "oneTimeFee": "0",
            "recurringFee": "102",
            "setupFee": "0",
            "sort": 0,
        }
    ]
}]

getVSDiskItemPrices = [
    {
        "id": 2255,
        "locationGroupId": None,
        "categories": [
            {
                "categoryCode": "guest_disk1",
                "id": 82,
                "name": "Second Disk",
                "quantityLimit": 0,
                "sortOrder": None
            },
            {
                "categoryCode": "guest_disk2",
                "id": 92,
                "name": "Third Disk",
                "quantityLimit": 0,
                "sortOrder": None
            },
            {
                "categoryCode": "guest_disk3",
                "id": 93,
                "name": "Fourth Disk",
                "quantityLimit": 0,
                "sortOrder": None
            },
            {
                "categoryCode": "guest_disk4",
                "id": 116,
                "name": "Fifth Disk",
                "quantityLimit": 0,
                "sortOrder": None
            }
        ],
        "item": {
            "capacity": "10",
            "description": "10 GB (SAN)",
            "keyName": "GUEST_DISK_10_GB_SAN"
        }
    },
    {
        "id": 1639,
        "locationGroupId": None,
        "categories": [
            {
                "categoryCode": "guest_disk0",
                "id": 81,
                "name": "First Disk",
                "quantityLimit": 0,
                "sortOrder": None
            }
        ],
        "item": {
            "capacity": "10",
            "description": "10 GB (SAN)",
            "keyName": "GUEST_DISK_10_GB_SAN"
        }
    }
]

getItemsOS = [{
    "description": "Debian GNU/Linux 6.x Squeeze/Stable - LAMP Install (64 bit)",
    "id": 3975,
    "itemTaxCategoryId": 166,
    "keyName": "OS_DEBIAN_6_X_SQUEEZE_LAMP_64_BIT",
    "softwareDescriptionId": 881,
    "itemCategory": {
        "categoryCode": "os",
        "id": 12,
        "name": "Operating System",
    },
    "prices": [
        {
            "hourlyRecurringFee": "0",
            "id": 14056,
            "itemId": 3975,
            "laborFee": "0",
            "recurringFee": "0",
            "setupFee": "0",
            "packageReferences": [
                {
                    "id": 74660,
                    "itemPriceId": 14056,
                    "packageId": 46
                }
            ]
        }
    ]
}]
