getAllObjects = [
    {
        'backendRouterId': 117917,
        'backendRouterName': 'bcr01a.ams01',
        'datacenterId': 265592,
        'datacenterLongName': 'Amsterdam 1',
        'datacenterName': 'ams01',
        'frontendRouterId': 117960,
        'frontendRouterName': 'fcr01a.ams01',
        'name': 'ams01.pod01'
    },
    {
        'backendRouterId': 1115295,
        'backendRouterName': 'bcr01a.wdc07',
        'datacenterId': 2017603,
        'datacenterLongName': 'Washington 7',
        'datacenterName': 'wdc07',
        'frontendRouterId': 1114993,
        'frontendRouterName': 'fcr01a.wdc07',
        'name': 'wdc07.pod01'
    },
    {
        'backendRouterId': 1234567,
        'backendRouterName': 'bcr01a.wdc07',
        'datacenterId': 2017603,
        'datacenterLongName': 'Washington 7',
        'datacenterName': 'wdc07',
        'frontendRouterId': 258741369,
        'frontendRouterName': 'fcr01a.wdc07',
        'name': 'TEST00.pod2'
    }
]
