getAllObjects = [
    {'description': 'Email about your order.',
     'enabled': True,
     'id': 1,
     'name': 'Order Being Reviewed'
     },
    {'description': 'Maintenances that will or are likely to cause service '
                    'outages and disruptions',
     'enabled': True,
     'id': 8,
     'name': 'High Impact'
     },
    {'description': 'Testing description.',
     'enabled': True,
     'id': 111,
     'name': 'Test notification'
     }
]

enable = True

disable = True
