getAllObjects = [{'id': 4, 'keyname': 'DNS', 'name': 'DNS'},
                 {'id': 5, 'keyname': 'FTP', 'name': 'FTP'},
                 {'id': 2, 'keyname': 'HTTP', 'name': 'HTTP'},
                 {'id': 41, 'keyname': 'HTTPS', 'name': 'HTTPS'},
                 {'id': 3, 'keyname': 'TCP', 'name': 'TCP'},
                 {'id': 6, 'keyname': 'UDP', 'name': 'UDP'}]
