getAllCancellationRequests = [
    {"createDate": "2023-04-20T06:53:17-06:00",
     "id": 123456,
     "ticketId": 147258,
     "itemCount": 1,
     "items": [
         {
             "billingItemId": 369852,
             "id": 147852369,
             "billingItem": {
                 "cancellationDate": "2023-05-03T22:59:59-06:00",
                 "categoryCode": "server",
             }
         }
     ],
     "status": {
         "id": 4,
         "name": "Approved"
     },
     "user": {
         "firstName": "CHRISTOPHER",
         "id": 167758,
         "lastName": "GALLO"
     }
     }]
