getObject = {
    "cooldown": None,
    "createDate": "2019-09-27T06:30:14+08:00",
    "id": 11111,
    "name": "prime-poly",
    "scaleGroupId": 2255111,
    "scaleGroup": {
        "accountId": 31111,
        "cooldown": 1800,
        "createDate": "2018-05-01T03:07:40+08:00",
        "id": 2252222,
        "lastActionDate": "2019-09-28T02:31:47+08:00",
        "maximumMemberCount": 6,
        "minimumMemberCount": 2,
        "modifyDate": "2019-09-28T02:31:50+08:00",
        "name": "ajcb-autoscale11",
        "regionalGroupId": 663,
        "terminationPolicyId": 2,
        "virtualGuestMemberTemplate": {
            "accountId": 31111,
            "domain": "techsupport.com",
            "hostname": "ajcb-autoscale22",
            "id": None,
            "maxMemory": 1024,
            "postInstallScriptUri": "https://pastebin.com/raw/62wrEKuW",
            "startCpus": 1,
            "blockDevices": [
                {
                    "device": "0",
                    "diskImage": {
                        "capacity": 25,
                    }
                },
                {
                    "device": "2",
                    "diskImage": {
                        "capacity": 10,
                    }
                }
            ],
            "datacenter": {
                "id": None,
                "name": "sao01",
            },
            "networkComponents": [
                {
                    "maxSpeed": 100,
                }
            ],
            "operatingSystemReferenceCode": "CENTOS_LATEST",
            "sshKeys": [
                {
                    "id": 490279,
                }
            ]
        }
    }
}
