getObject = {
    'accountId': 307608,
    'createDate': '2015-05-05T16:23:52-06:00',
    'id': 11449,
    'modifyDate': '2015-05-05T16:24:09-06:00',
    'name': 'TEST307608-1',
    'typeId': 2,
    'description': 'Citrix NetScaler VPX 10.5 10Mbps Standard',
    'managementIpAddress': '10.11.11.112',
    'outboundPublicBandwidthUsage': '.00365',
    'primaryIpAddress': '19.4.24.16',
    'datacenter': {
        'longName': 'Dallas 9',
        'name': 'dal09',
    },
    "networkVlans": [
        {
            "accountId": 11111,
            "id": 33333,
            "modifyDate": "2019-07-17T01:09:38+08:00",
            "name": "FirewallTesting",
            "primarySubnetId": 91111,
            "vlanNumber": 1711
        },
        {
            "accountId": 11111,
            "id": 862222,
            "modifyDate": "2019-07-17T01:09:42+08:00",
            "primarySubnetId": 502211,
            "vlanNumber": 722
        }
    ],
    'password': {
        'password': 'aaaaa',
        'username': 'root'
    },
    "subnets": [
        {
            "broadcastAddress": "",
            "cidr": 32,
            "gateway": "",
            "id": 74222,
            "modifyDate": "2016-10-26T23:39:12+08:00",
            "netmask": "255.255.255.255",
            "networkIdentifier": "159.253.111.111",
            "networkVlanId": 3611111,
            "sortOrder": "4",
            "subnetType": "STATIC_IP_ROUTED",
            "totalIpAddresses": "2",
            "usableIpAddressCount": "2",
            "version": 4,
            "addressSpace": "PUBLIC"
        }
    ],
    'type': {
        'keyName': 'NETSCALER_VPX',
        'name': 'NetScaler VPX'
    }
}
