getObject = {
    "id": 11111,
    "allowedVirtualGuests": [
        {
            "id": 22222,
            "allowedHost": {
                "accountId": 12345,
                "id": 18311111,
                "name": "iqn.2020-03.com.ibm:sl02su11111-v62941551",
                "resourceTableId": 6222222,
                "resourceTableName": "VIRTUAL_GUEST",
                "credential": {
                    "accountId": "12345",
                    "createDate": "2020-03-20T13:35:47-06:00",
                    "id": 1522222,
                    "nasCredentialTypeId": 2,
                    "password": "SjFDCpHrmKewos",
                    "username": "SL02SU322222-V62922222"
                }
            }
        }
    ]
}
