findByHardwareId = [
    {
        'hardwareId': 147258,
        'id': 1232569,
        'userId': 3698,
        'hardware': {
            'accountId': 963258,
            'domain': 'testedit.com',
            'fullyQualifiedDomainName': 'testslcli.testedit.com',
            'hostname': 'bardcabero',
            'id': 1403539,
            'notes': 'My golang note',
            'provisionDate': '2020-04-27T16:10:56-06:00',
        },
        'user': {
            'accountId': 307608,
            'email': 'cgallo@us.ibm.com',
            'firstName': 'CHRISTOPHER',
            'id': 167758,
            'lastName': 'GALLO',
            'username': 'SL307608',
        }
    },
    {
        'hardwareId': 1403539,
        'id': 1408587,
        'userId': 9734826,
        'hardware': {
            'accountId': 963258,
            'domain': 'testedit.com',
            'fullyQualifiedDomainName': 'testslcli.testedit.com',
            'hostname': 'bardcabero',
            'id': 1403539,
            'notes': 'My golang note',
            'provisionDate': '2020-04-27T16:10:56-06:00',
        },
        'user': {
            'accountId': 307608,
            'email': 'Brian.Flores@ibm.com',
            'firstName': 'Brian',
            'id': 9734826,
            'lastName': 'Flores',
            'username': '307608_brian.flores@ibm.com',
        }
    }
]

createObject = {
    'hardwareId': 1403539,
    'id': 1408593,
    'userId': 7650493,
    'hardware': {
        'accountId': 307608,
        'domain': 'testedit.com',
        'fullyQualifiedDomainName': 'bardcabero.testedit.com',
        'hostname': 'bardcabero',
        'id': 1403539,
        'notes': 'My golang note',

    },
    'user': {
        'accountId': 307608,
        'email': 'daniel.cabero@jalasoft.com',
        'firstName': 'daniel',
        'id': 7650493,
        'lastName': 'cabero',
        'username': 'sl307608-dcabero'

    }
}

deleteObjects = True
