getAllObjects = [
    {
        "id": 1001,
        "name": "Accounting Request"
    },
    {
        "id": 1002,
        "name": "Sales Request"
    },
    {
        "id": 1003,
        "name": "Reboots and Console Access"
    },
    {
        "id": 1004,
        "name": "DNS Request"
    },
    {
        "id": 1005,
        "name": "Hardware Issue"
    }
]
