getObject = {
    "id": 405,
    "keyName": "AC1_8X60X25",
    "prices": [
        {
            "hourlyRecurringFee": "1.425",
            "id": 207345,
            "recurringFee": "936.23",
            "item": {
                "description": "1 x P100 GPU",
                "id": 10933,
                "keyName": "1_X_P100_GPU",
                "itemCategory": {
                    "categoryCode": "guest_pcie_device0",
                    "id": 1259
                }
            }
        },
        {
            "hourlyRecurringFee": "0",
            "id": 2202,
            "recurringFee": "0",
            "item": {
                "description": "25 GB (SAN)",
                "id": 1178,
                "keyName": "GUEST_DISK_25_GB_SAN",
                "itemCategory": {
                    "categoryCode": "guest_disk0",
                    "id": 81
                }
            }
        },
        {
            "hourlyRecurringFee": ".342",
            "id": 207361,
            "recurringFee": "224.69",
            "item": {
                "description": "60 GB",
                "id": 10939,
                "keyName": "RAM_0_UNIT_PLACEHOLDER_10",
                "itemCategory": {
                    "categoryCode": "ram",
                    "id": 3
                }
            }
        },
        {
            "hourlyRecurringFee": ".181",
            "id": 209595,
            "recurringFee": "118.26",
            "item": {
                "capacity": 8,
                "description": "8 x 2.0 GHz or higher Cores",
                "id": 11307,
                "keyName": "GUEST_CORE_8",
                "itemCategory": {
                    "categoryCode": "guest_core",
                    "id": 80
                }
            }
        }
    ]
}
