"""
    SoftLayer.CLI
    ~~~~~~~~~~~~~~
    Contains all code related to the CLI interface

    :license: MIT, see LICENSE for more details.
"""
# pylint: disable=w0401, invalid-name

from SoftLayer.CLI.helpers import *  # NOQA
