createObject = {
    "createDate": "2022-10-18T09:27:48-06:00",
    "id": 78026761,
    "notes": "test slcli",
    "password": "123456",
    "softwareId": 67064532,
    "username": "testslcli",
    "software": {
        "hardwareId": 1532729,
        "id": 67064532,
        "manufacturerLicenseInstance": ""
    }
}
