updateLoadBalancerHealthMonitors = {
    'backendPort': 80,
    'backendProtocol': 'HTTP',
    'healthMonitorUuid': '1a1aa111-4474-4e16-9f02-4de959244444',
    'interval': 50,
    'maxRetries': 10,
    'timeout': 10,
    'urlPath': None
}
