getAllObjects = [{'id': 21,
                  'keyname': 'CONSISTENT_HASH_IP',
                  'name': 'Consistent Hash IP'},
                 {'id': 9,
                  'keyname': 'INSERT_COOKIE',
                  'name': 'Insert Cookie'},
                 {'id': 1,
                  'keyname': 'LEAST_CONNECTIONS',
                  'name': 'Least Connections'},
                 {'id': 7,
                  'keyname': 'LEAST_CONNECTIONS_INSERT_COOKIE',
                  'name': 'Least Connections with Inserted Cookie'},
                 {'id': 4,
                  'keyname': 'LEAST_CONNECTIONS_PERSISTENT_IP',
                  'name': 'Least Connections with Persistent IP'},
                 {'id': 11,
                  'keyname': 'PERSISTENT_IP',
                  'name': 'Persistent IP'},
                 {'id': 10,
                  'keyname': 'ROUND_ROBIN',
                  'name': 'Round Robin'},
                 {'id': 6,
                  'keyname': 'ROUND_ROBIN_INSERT_COOKIE',
                  'name': 'Round Robin with Inserted Cookie'},
                 {'id': 3,
                  'keyname': 'ROUND_ROBIN_PERSISTENT_IP',
                  'name': 'Round Robin with Persistent IP'},
                 {'id': 2,
                  'keyname': 'SHORTEST_RESPONSE',
                  'name': 'Shortest Response'},
                 {'id': 8,
                  'keyname': 'SHORTEST_RESPONSE_INSERT_COOKIE',
                  'name': 'Shortest Response with Inserted Cookie'},
                 {'id': 5,
                  'keyname': 'SHORTEST_RESPONSE_PERSISTENT_IP',
                  'name': 'Shortest Response with Persistent IP'}]
