getMappingUsageMetrics = [
    {
        "names": [
            "TotalBandwidth",
            "TotalHits",
            "HitRatio"
        ],
        "totals": [
            1.0,
            3,
            2.0
        ],
        "type": "TOTALS"
    }
]
