cancelService = True
cancelServiceOnAnniversaryDate = True
cancelItem = True

getObject = {
    "allowCancellationFlag": 1,
    "cancellationDate": "None",
    "categoryCode": "server",
    "createDate": "2015-05-28T10:36:38-06:00",
    "cycleStartDate": "2020-04-03T23:12:05-06:00",
    "description": "Dual E5-2690 v3 (12 Cores, 2.60 GHz)",
    "domainName": "sl-test.com",
    "hostName": "testsangeles101",
    "id": 53897671,
    "lastBillDate": "2020-04-03T23:12:05-06:00",
    "modifyDate": "2020-04-03T23:12:07-06:00",
    "nextBillDate": "2020-05-03T23:00:00-06:00",
    "orderItemId": 68634907,
    "parentId": "None",
    "recurringFee": "1000",
    "recurringMonths": 1,
    "children": [
        {
            "allowCancellationFlag": 1,
            "associatedBillingItemId": "53897671",
            "cancellationDate": "None",
            "categoryCode": "second_processor",
            "createDate": "2015-05-28T10:36:38-06:00",
            "cycleStartDate": "2020-04-03T23:12:05-06:00",
            "description": "E5-2690 v3 (12 Cores, 2.60 GHz)",
            "id": 53897673,
            "lastBillDate": "2020-04-03T23:12:05-06:00",
            "modifyDate": "2020-04-03T23:12:07-06:00",
            "nextBillDate": "2020-05-03T23:00:00-06:00",
            "oneTimeFee": "0",
            "oneTimeFeeTaxRate": "0",
            "orderItemId": 68634909,
            "parentId": 53897671,
            "recurringFee": "1000",
            "setupFeeTaxRate": "0"
        },
    ],
    "hourlyFlag": False,
    "location": {
        "id": 265592,
        "longName": "Amsterdam 1",
        "name": "ams01",
        "statusId": 2
    },
    "nextInvoiceTotalRecurringAmount": 0,
    "orderItem": {
        "id": 68634907,
        "order": {
            "id": 4546175,
            "userRecord": {
                "displayName": "Tester",
                "email": "test@us.ibm.com",
                "id": 167758,
                "userStatus": {
                    "keyName": "ACTIVE",
                    "name": "Active"
                }
            }
        }
    },
    "resourceTableId": "None"
}
