findByGuestId = [
    {
        'guestId': 100,
        'id': 123,
        'userId': 147852,
        'guest': {
            'domain': 'test.support.com',
            'fullyQualifiedDomainName': 'adns.test.support.com',
            'hostname': 'adns',
            'id': 123,
            'maxCpu': 4,
            'maxCpuUnits': 'CORE',
            'maxMemory': 16384,
            'startCpus': 4,
            'statusId': 1001,
            'uuid': 'b395782d-2144-1f9c-0a90-28a7a5160d81',
        },
        'user': {
            'accountId': 147852,
            'displayName': 'TESTSUPPORT',
            'email': 'testsupport@us.ibm.com',
            'firstName': 'test',
            'id': 167758,
            'lastName': 'support',
            'username': 'test',
        }
    }
]

createObject = {
    'guestId': 100,
    'id': 123,
    'userId': 147852,
    'guest': {
        'domain': 'test.support.com',
        'fullyQualifiedDomainName': 'adns.test.support.com',
        'hostname': 'adns',
        'id': 123,
        'maxCpu': 4,
        'maxCpuUnits': 'CORE',
        'maxMemory': 16384,
        'startCpus': 4,
        'statusId': 1001,
        'uuid': 'b395782d-2144-1f9c-0a90-28a7a5160d81',
    },
    'user': {
        'accountId': 147852,
        'displayName': 'TESTSUPPORT',
        'email': 'testsupport@us.ibm.com',
        'firstName': 'test',
        'id': 167758,
        'lastName': 'support',
        'username': 'test',
    }
}

deleteObjects = True
