getAllObjects = [{
    "capacity": "4",
    "key": "ABCDE-6CJ8L-J8R9H-000R0-CDR70",
    "units": "CPU",
    "billingItem": {
        "allowCancellationFlag": 1,
        "categoryCode": "software_license",
        "createDate": "2018-10-22T11:16:48-06:00",
        "cycleStartDate": "2021-06-03T23:11:22-06:00",
        "description": "vCenter Server Appliance 6.0",
        "id": 123654789,
        "lastBillDate": "2021-06-03T23:11:22-06:00",
        "modifyDate": "2021-06-03T23:11:22-06:00",
        "nextBillDate": "2021-07-03T23:00:00-06:00",
        "orderItemId": 385054741,
        "recurringMonths": 1,
        "serviceProviderId": 1,
    },
    "softwareDescription": {
        "id": 1529,
        "longDescription": "VMware vCenter 6.0",
        "manufacturer": "VMware",
        "name": "vCenter",
        "version": "6.0",
        "requiredUser": "administrator@vsphere.local"
    }
},
    {
        "capacity": "1",
        "key": "CBERT-4RL92-K8999-031K4-AJF5J",
        "units": "CPU",
        "billingItem": {
            "allowCancellationFlag": 1,
            "categoryCode": "software_license",
            "createDate": "2021-06-09T14:51:38-06:00",
            "cycleStartDate": "2021-06-09T14:51:38-06:00",
            "description": "VMware vSAN Advanced Tier III 64 - 124 TB 6.x",
            "id": 369852174,
            "nextBillDate": "2021-07-03T23:00:00-06:00",
            "orderItemId": 836502628,
            "recurringMonths": 1,
            "serviceProviderId": 1,
        },
        "softwareDescription": {
            "id": 1795,
            "longDescription": "VMware Virtual SAN Advanced Tier III 6.2",
            "manufacturer": "VMware",
            "name": "Virtual SAN Advanced Tier III",
            "version": "6.2",
        }
}]
