getAllObjects = [
    {
        "key": "T_1",
        "keyName": "TICKET_VIEW",
        "name": "View Tickets"
    },
    {
        "key": "T_2",
        "keyName": "TEST",
        "name": "A Testing Permission"
    },
    {
        "key": "T_3",
        "keyName": "TEST_3",
        "name": "A Testing Permission 3"
    },
    {
        "key": "T_4",
        "keyName": "TEST_4",
        "name": "A Testing Permission 4"
    },
    {
        "key": "T_5",
        "keyName": "ACCESS_ALL_HARDWARE",
        "name": "A Testing Permission 5"
    },
    {
        'key': 'ALL_1',
        'keyName': 'ACCESS_ALL_HARDWARE',
        'name': 'All Hardware Access'
    },
    {
        'key': 'A_1',
        'keyName': 'ACCOUNT_SUMMARY_VIEW',
        'name': 'View Account Summary'
    },
    {
        'key': 'A_10',
        'keyName': 'ADD_SERVICE_STORAGE',
        'name': 'Add/Upgrade Storage (StorageLayer)'
    }
]
