deleteObject = True
editObject = True
getObject = {'id': 1234,
             'fingerprint': 'aa:bb:cc:dd',
             'label': 'label',
             'notes': 'notes',
             'key': 'ssh-rsa AAAAB3N...pa67 user@example.com'}
createObject = getObject
getAllObjects = [getObject]
