getAllObjects = [
    {
        "description": "All Datacenters in the USA and Canada.",
        "id": 1,
        "locationGroupTypeId": 1,
        "name": "US/Canada",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Amsterdam, London, Paris, and Madrid.",
        "id": 2,
        "locationGroupTypeId": 1,
        "name": "AMS/LON/MAD/PAR",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Singapore, Hong Kong and Japan.",
        "id": 3,
        "locationGroupTypeId": 1,
        "name": "SNG/HKG/JPN",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Australia",
        "id": 222,
        "locationGroupTypeId": 1,
        "name": "AUS",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Mexico",
        "id": 262,
        "locationGroupTypeId": 1,
        "name": "MEX",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Brazil",
        "id": 665,
        "locationGroupTypeId": 1,
        "name": "BRA",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in India",
        "id": 745,
        "locationGroupTypeId": 1,
        "name": "IND",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Italy",
        "id": 863,
        "locationGroupTypeId": 1,
        "name": "ITA",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in South Korea",
        "id": 1023,
        "locationGroupTypeId": 1,
        "name": "KOR",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    },
    {
        "description": "All Datacenters in Frankfurt",
        "id": 2023,
        "locationGroupTypeId": 1,
        "name": "FRA",
                "securityLevelId": None,
                "locationGroupType": {
                    "name": "VDR"
                }
    }
]
