getGuests = [
    {
        "accountId": 11111,
        "createDate": "2019-09-05T17:03:42-06:00",
        "fullyQualifiedDomainName": "NSX-T Manager",
        "hostname": "NSX-T Manager",
        "id": 22222,
        "maxCpu": 16,
        "maxCpuUnits": "CORE",
        "maxMemory": 49152,
        "startCpus": 16,
        "powerState": {
            "keyName": "RUNNING",
            "name": "Running"
        },
        "status": {
            "keyName": "ACTIVE",
            "name": "Active"
        }
    },
    {
        "accountId": 11111,
        "createDate": "2019-09-23T06:00:53-06:00",
        "hostname": "NSX-T Manager2",
        "id": 33333,
        "maxCpu": 12,
        "maxCpuUnits": "CORE",
        "maxMemory": 49152,
        "startCpus": 12,
        "statusId": 1001,
        "powerState": {
            "keyName": "RUNNING",
            "name": "Running"
        },
        "status": {
            "keyName": "ACTIVE",
            "name": "Active"
        }
    }
]
