getDatacenters = [
    {
        "id": 1441195,
        "longName": "Dallas 10",
        "name": "dal10"
    },
    {
        "id": 449494,
        "longName": "Dallas 9",
        "name": "dal09"
    }
]

getHardwareRouters = []
