getAccountOverview = {
    "creditsAllowed": 25000,
    "creditsOverage": 0,
    "creditsRemain": 25000,
    "creditsUsed": 0,
    "package": "Free Package",
    "reputation": 100,
    "requests": 56
}

getStatistics = [{
    "blocks": 0,
    "bounces": 0,
    "clicks": 0,
    "date": "2021-04-28",
    "delivered": 0,
    "invalidEmail": 0,
    "opens": 0,
    "repeatBounces": 0,
    "repeatSpamReports": 0,
    "repeatUnsubscribes": 0,
    "requests": 0,
    "spamReports": 0,
    "uniqueClicks": 0,
    "uniqueOpens": 0,
    "unsubscribes": 0
}]

getObject = {
    "accountId": 123456,
    "createDate": "2020-07-06T10:29:11-06:00",
    "id": 1232123,
    "password": "Test123456789",
    "typeId": 21,
    "username": "techsupport3@ie.ibm.com",
    "vendorId": 1,
    "billingItem": {
        "categoryCode": "network_message_delivery",
        "description": "Free Package",
        "id": 695735054,
        "notes": "techsupport3@ie.ibm.com",
    },
    "type": {
        "description": "Delivery of messages through e-mail",
        "id": 21,
        "keyName": "EMAIL",
        "name": "Email"
    },
    "vendor": {
        "id": 1,
        "keyName": "SENDGRID",
        "name": "SendGrid"
    },
    "emailAddress": "techsupport3@ie.ibm.com",
    "smtpAccess": "1"
}

editObject = True
updateEmailAddress = True
