createObject = {
                'createDate': '2023-03-22T06:37:45-06:00',
                'id': 207054,
                'name': 'testslcli',
                'uri': 'http://slclitest.com',
                'hookType': {}
}
deleteObject = True
