getFrontendMacAddresses = ['06-00-00-00-00-00']
getBackendMacAddresses = ['07-00-00-00-00-00']
getFrontendMacAddresses = ['06-00-00-00-00-00']
getRouter = 'brc01'
getVlans = [10, 124]
getVlanIds = [8384, 12446]
getDatacenter = 'dal01'
getUserMetadata = 'User-supplied data'
