getObject = {
    "certificate": "-----BEGIN CERTIFICATE----- \nMIIEJTCCAw2gAwIBAgIDCbQ0MA0GCSqGSIb3DQEBCwUAMEcxCzAJBgNVBAYTAlVT"
                   " -----END CERTIFICATE-----",
    "certificateSigningRequest": "-----BEGIN CERTIFICATE REQUEST-----\n"
                                 "MIIC1jCCAb4CAQAwgZAxCzAJBgNVBAYTAlVTMQ4wDAYDVQQIDAVUZXhh123456QMA4G\n"
                                 "-----END CERTIFICATE REQUEST-----",
    "commonName": "techbabble.xyz",
    "createDate": "2016-01-20T10:56:44-06:00",
    "id": 123456,
    "intermediateCertificate": "",
    "keySize": 258369,
    "modifyDate": "2019-06-05T14:10:40-06:00",
    "organizationName": "Unspecified",
    "privateKey": "-----BEGIN RSA PRIVATE KEY-----\nMIIEpAIBAAKCAQEA3SwTZ7sh7we5zIbmtSbxGJxff07eutrK12345678WXtwQSdE\n"
                  "-----END RSA PRIVATE KEY-----",
    "validityBegin": "2016-01-19T17:59:37-06:00",
    "validityDays": 0,
    "validityEnd": "2017-01-20T13:48:41-06:00"
}
createObject = {}
editObject = True
deleteObject = True
