getAllObjects = [
    {'id': 21, 'keyname': 'DEFAULT', 'name': 'Default'},
    {'id': 3, 'keyname': 'DNS', 'name': 'DNS'},
    {'id': 2, 'keyname': 'HTTP', 'name': 'HTTP'},
    {'id': 5, 'keyname': 'HTTP-CUSTOM', 'name': 'HTTP-CUSTOM'},
    {'id': 4, 'keyname': 'ICMP', 'name': 'Ping'},
    {'id': 1, 'keyname': 'TCP', 'name': 'TCP'}
]
